@@ -1,3 +1,8 @@
+# Module: Association Rules Mining
+# Author: Moez Ali <moez.ali@queensu.ca>
+# License: MIT
+
+
 def setup(data, 
           transaction_id, 
           item_id,
@@ -8,22 +13,23 @@ def setup(data,
       
     Description:
     ------------
-    This function initialize the environment in pycaret. setup() must called before
-    executing any other function in pycaret. It takes three mandatory parameters i.e.
+    This function initializes the environment in pycaret. setup() must called before
+    executing any other function in pycaret. It takes three mandatory parameters:
     (i) dataframe {array-like, sparse matrix}, (ii) transaction_id param identifying 
     basket and (iii) item_id param used to create rules. These three params are 
     normally found in any transactional dataset. pycaret will internally convert the
-    dataframe into sparse matrix required for association rules mining.
+    dataframe into a sparse matrix which is required for association rules mining.
     
         Example
         -------
-        experiment_name = setup(data, 'InvoiceNo', 'ProductName')
+        from pycaret.datasets import get_data
+        france get_data('france')
         
-        where data is of type dataframe. 
+        experiment_name = setup(data = data, transaction_id = 'InvoiceNo', 
+                                item_id = 'ProductName')
         
     Parameters
     ----------
-
     data : {array-like, sparse matrix}, shape (n_samples, n_features) where n_samples 
     is the number of samples and n_features is the number of features.
 
@@ -38,10 +44,9 @@ def setup(data,
     list of strings to be ignored when considering rule mining.
 
     session_id: int, default = None
-    If None, random seed is generated and returned in Information grid. The unique number 
-    is then distributed as a seed in all other functions used during experiment. This can
-    be used later for reproducibility of entire experiment.
-
+    If None, a random seed is generated and returned in the Information grid. The 
+    unique number is then distributed as a seed in all functions used during the 
+    experiment. This can be used for later reproducibility of the entire experiment.
 
     Returns:
     --------
@@ -50,11 +55,10 @@ def setup(data,
     -----------      
 
     environment:  This function returns various outputs that are stored in variable
-    -----------   as tuple. They are being used by other functions in pycaret.
+    -----------   as tuple. They are used by other functions in pycaret.
 
     Warnings:
     ---------
-    
     None
     
     
@@ -123,23 +127,23 @@ def create_model(metric='confidence',
      
     Description:
     ------------
-    This function creates a association rule model using data and identified passed
-    at setup stage. This function internally transforms the data for association
-    rule mining.
+    This function creates an association rules model using data and identifiers 
+    passed at setup stage. This function internally transforms the data for 
+    association rule mining.
 
     setup() function must be called before using create_model()
 
         Example
         -------
-        arule = create_model()
+        from pycaret.datasets import get_data
+        france get_data('france')        
+        experiment_name = setup(data = data, transaction_id = 'InvoiceNo', 
+                                item_id = 'ProductName')
 
-        This will return dataframe containing rules sorted by metric param. It will
-        include antecedents and consequens of rule along with support, confidence,
-        lift, leverage and conviction.
+        This will return dataframe containing rules sorted by metric param. 
 
     Parameters
     ----------
-
     metric : string, default = 'confidence'
     Metric to evaluate if a rule is of interest. Default is set to confidence. 
     Other available metrics include 'support', 'lift', 'leverage', 'conviction'. 
@@ -226,6 +230,7 @@ def create_model(metric='confidence',
     return(rules)
 
 
+
 def plot_model(model,
                plot = '2d'):
     
@@ -334,117 +339,21 @@ def plot_model(model,
         fig.show()   
 
 
-def save_experiment(experiment_name=None):
-    
-        
-    """
-          
-    Description:
-    ------------
-    This function saves the entire experiment in current active directory. All 
-    the outputs using pycaret are internally saved into a binary list which is
-    pickilized when save_experiment() is used. 
-    
-        Example:
-        --------
-        
-        save_experiment()
-        
-        This will save the entire experiment in current active directory. By 
-        default name of experiment will use session_id generated during setup().
-        To use custom name, experiment_name param has to be passed as string.
-        
-        For example:
-        
-        save_experiment('experiment_23122019')
 
-    Parameters
-    ----------
-    
-    experiment_name : string, default = none
-    Name of pickle file to be passed as a string.
-
-    Returns:
-    --------    
-    Success Message
-    
-
-    Warnings:
-    ---------
-    None    
-       
-         
-    """
-    
-    #general dependencies
-    import joblib
-    global experiment__
-    
-    #defining experiment name
-    if experiment_name is None:
-        experiment_name = 'experiment_' + str(seed)
-        
-    else:
-        experiment_name = experiment_name  
-        
-    experiment_name = experiment_name + '.pkl'
-    joblib.dump(experiment__, experiment_name)
-    
-    print('Experiment Succesfully Saved')
-
-
-def load_experiment(experiment_name):
+def get_rules(data, 
+              transaction_id, 
+              item_id,
+              ignore_items = None,
+              metric='confidence',
+              threshold = 0.5,
+              min_support = 0.05):
     
     """
-          
-    Description:
-    ------------
-    This function loads the prior saved experiment from current active directory 
-    into current python notebook. Load object must be a pickle file.
+    Magic function to get Association Rules in Power Query / Power BI.    
     
-        Example:
-        --------
-        
-        saved_experiment = load_experiment('experiment_23122019')
-        
-        This will load the entire experiment pipeline into object saved_experiment
-        using experiment_name param. The experiment file must be in current directory.
-        
-        
-    Parameters
-    ----------
-    
-    experiment_name : string, default = none
-    Name of pickle file to be passed as a string.
-
-    Returns:
-    --------    
-    Information Grid containing details of saved objects in experiment pipeline.
-    
-
-    Warnings:
-    ---------
-    None    
-       
-         
     """
     
-    #general dependencies
-    import joblib
-    import pandas as pd
+    s = setup(data=data, transaction_id=transaction_id, item_id=item_id, ignore_items = ignore_items)
+    dataset = create_model(metric=metric, threshold=threshold, min_support=min_support, round=4)
     
-    experiment_name = experiment_name + '.pkl'
-    temp = joblib.load(experiment_name)
-    
-    name = []
-    exp = []
-
-    for i in temp:
-        name.append(i[0])
-        exp.append(i[-1])
-
-    ind = pd.DataFrame(name, columns=['Object'])
-    display(ind)
-
-    return exp
-
+    return dataset
\ No newline at end of file
